#!/bin/bash
####script below assumes gromacs is compiled#####
#################################################

####Equilibration at 310 K
####Make a topology file using structure and force field for simulation.
echo 6 1 | gmx pdb2gmx -f ini_struc/q72-310k-initial.gro -ignh -o polyq72.gro

####Prepare a simulaton box. For IDP, box dimension need to be large enough to prevent any periodic image interaction.
gmx editconf -f polyq72.gro -o box.gro -c -d 1.0 -bt cubic

####Solvating a simulation box.
gmx solvate -cp box.gro -cs spc216.gro -o solv.gro -p topol.top

####Adding counter ions to neutralize the box. Replace "SOL" while adding ions.
gmx grompp -f ions.mdp -c solv.gro -p topol.top -o ions.tpr -maxwarn 1
echo 13 | gmx genion -s ions.tpr -o solv-ions.gro -p topol.top -pname NA -nname CL -neutral -conc 0.125

####Energy minimization.
gmx grompp -f minim.mdp -c solv_ions.gro -p topol.top -o em.tpr
gmx mdrun -deffnm em

####Position restrain.
gmx grompp -f posre.mdp -c em.gro -r em.gro -p topol.top -o posre.tpr
gmx mdrun -deffnm posre

####Npt equilibration.
gmx grompp -f npt.mdp -c posre.gro -r posre.gro -p topol.top -o npt.tpr
gmx mdrun -deffnm npt
