#!/bin/bash
####script below assumes gromacs is compiled#####
#################################################

####Make a topology file using structure and force field for simulation. Make sure to have a structure file of a protein (e.g., histatin5.pdb) and a force field directory if one is using a different force field other than the available in the compiled version of the gromacs. pdb2gmx asks to choose a force field and water model. In this example, it will choose the force field and water model listed in option 1. Check and make sure.
echo 6 1 | gmx pdb2gmx -f 8f20_resp_GMX.gro -ignh -o 8f20_resp.gro

####Prepare a simulaton box. For IDP, box dimension need to be large enough to prevent any periodic image interaction.
gmx editconf -f 8f20_resp.gro -o box.gro -c -d 1.0 -bt cubic

####Energy minimization.
gmx grompp -f minim.mdp -c box.gro -p topol.top -o em.tpr
gmx mdrun -deffnm em

####Position restrain.
gmx grompp -f posre.mdp -c em.gro -r em.gro -p topol.top -o posre.tpr
gmx mdrun -deffnm posre

####Npt equilibration.
gmx grompp -f npt.mdp -c posre.gro -r posre.gro -p topol.top -o npt.tpr
gmx mdrun -deffnm npt

####Nvt equilibration.
gmx grompp -f nvt.mdp -c npt.gro -r npt.gro -p topol.top -o nvt.tpr
gmx mdrun -deffnm nvt

####Production equilibration.
gmx grompp -f production.mdp -c nvt.gro -r nvt.gro -p topol.top -o production.tpr
gmx mdrun -deffnm production


