#!/bin/bash
####script below assumes gromacs is compiled#####
#################################################

#################################################
####The initial structures of Htt-exon-1 proteins were selected from the first 100 ns-long REST simulations of the apo systems. 
####In detail, we performed gromos clustering on the replica of 310 K and selected the central conformations of the top 16 clusters. 
####For each initial conformation, we inserted 3 ispinesib molecules via Gromacs tool insert-molecules, and the minimal distances of ispinesib molecules to proteins were larger than 10 Å. 
#################################################
#################################################
####Use Pymol to remove some of the water molecules, ensuring that the total number of molecules is consistent for each system.
####Modify the topol.top file to be consistent with the structure file
####The initial structures are in the folder "./ini_struc"
#################################################

####Energy minimization.
j=0
for ((i=0;i!=16;i++))
do
mkdir test$j
gmx grompp -f ./minim.mdp -c ./q72-8f20-$i.gro -p ./topol.top -o test$j/em_$j.tpr
gmx mdrun -s test$j/em_$j.tpr -o -c test$j/em_$j
j=$[j+1]
done

####Position restrain.
#### The temperature coupling was applied on two groups: Protein_MOL Water_and_ions. 
j=0
for ((i=0;i!=16;i++))
do
gmx grompp -f ./posre.mdp -c test$j/em_$j.gro -p ./topol.top -o test$j/posre_$j.tpr -r test$j/em_$j.gro -n ./index.ndx
gmx mdrun -s test$j/posre_$j.tpr -o -c test$j/posre_$j
j=$[j+1]
done

################################
####Scripts below are REST simulation.####
####PLUMED HREMD tutorial: https://www.plumed.org/doc-v2.5/user-doc/html/hrex.html#:~:text=When%20patching%20GROMACS%20with%20PLUMED,the%20-hrex%20flag%20of%20mdrun%20.

#number of replicas
nrep=16
# "effective" temperature range
tmin=310
tmax=461

####Make a new topology file (processed.top) using "topol.top". 
#processed.top should have all the parameters required for the simulation in a single file.
gmx grompp -f production.mdp -c posre_0.gro -pp processed.top

####Append "_" to solute atoms for which the Hamiltonian is to be scaled inside "processed.

####Process topology and prepare tpr file
dt=0.012
j=0
for ((i=0;i!=16;i++))
do
s=$(echo $dt $i | awk '{printf "%.6f\n",(1.0-$1*$2)*(1.0-$1*$2)}')
echo $s
plumed partial_tempering $s < ./processed.top > topol_$j.top
gmx grompp -f ./production.mdp -c test$j/posre_$j.gro -p topol_$j.top -o test$j/topol -n ./index.ndx -maxwarn 1
touch test$j/plumed.dat
j=$[j+1]
done

####Run REST simulation
mpirun -np 16 gmx_mpi mdrun -v -plumed plumed.dat -replex 500 -hrex -multidir test0 test1 test2 test3 test4 test5 test6 test7 test8 test9 test10 test11 test12 test13 test14 test15 -s topol.tpr
