import numpy as np
import matplotlib.pyplot as plt
from matplotlib import cm
from matplotlib.colors import ListedColormap, LinearSegmentedColormap
from mpl_toolkits.mplot3d import Axes3D
import sys
from numpy import *
import matplotlib as mpl
from matplotlib import rc


mpl.rcParams['font.family']='serif'
mpl.rcParams['figure.subplot.hspace'] = 0.01
mpl.rcParams['figure.subplot.wspace'] = 0.01
mpl.rcParams['lines.linewidth'] = 1.5
mpl.rcParams['figure.subplot.left'] = 0.001
mpl.rcParams['figure.subplot.right'] = 0.999
mpl.rcParams['figure.subplot.bottom'] = 0.01
mpl.rcParams['figure.subplot.top'] = 0.999

rc('text', usetex=True)
axis_font = {'fontname':'serif', 'size':'24', 'weight':'bold'}
axis_label = {'fontname':'serif', 'size':'24', 'weight':'bold'}
axis_font_label = {'fontsize':'24', 'weight':'bold'}

#load data
data = np.loadtxt('eval-q72.xvg')
eigval = np.array(data)

x1 = eigval[0:600000, 0]
y1 = eigval[0:600000, 1]
x2 = eigval[600001:1200001, 0]
y2 = eigval[600001:1200001, 1]
x1_min = x1.min()
y1_min = y1.min()
x2_min = x2.min()
y2_min = y2.min()
x1_max = x1.max()
y1_max = y1.max()
x2_max = x2.max()
y2_max = y2.max()
xrange = np.array([x1_min, x2_min, x1_max, x2_max])
yrange = np.array([y1_min, y2_min, y1_max, y2_max])
xmin = xrange.min()
xmax = xrange.max()
ymin = yrange.min()
ymax = yrange.max()
#binsx = 2*int(xmax-xmin)
#binsy = 2*int(ymax-ymin)
binsx = 70
binsy = 70

xbinwidth = (xmax - xmin)/binsx
ybinwidth = (ymax - ymin)/binsy

#calculate histogram2d
H,xedges,yedges = np.histogram2d(x1,y1, bins=[binsx, binsy], range=[[xmin-xbinwidth,xmax+xbinwidth],[ymin-ybinwidth,ymax+ybinwidth]], density=True)

print(np.shape(H))
H = H.T                # Let each row list bins with common y range.
#calculate x and y height
lnh = np.log(H)
pmf = -lnh
where_are_inf = np.isinf(pmf)
# pmf[where_are_inf] = np.max(pmf)
pmf[where_are_inf] = 12

plotx = np.linspace(xmin, xmax, binsx)
ploty = np.linspace(ymin, ymax, binsy)

##create new colormap
colors = ["maroon","firebrick", "salmon","wheat","wheat","skyblue", "aliceblue"]
newcmp = LinearSegmentedColormap.from_list("mycmap", colors)

# plt.rc('font', family = 'Times New Roman')
# plt.rcParams['font.size'] = 24
# fig = plt.figure(figsize=(10, 7))
fig = plt.figure(figsize=(5.5, 5.1))
ax=fig.add_subplot(111, projection='3d')
# ax.get_proj = lambda: np.dot(Axes3D.get_proj(ax), np.diag([0.5, 0.5, 1]))

#plt.title('Q72-apo', fontsize=36)
# plt.tick_params(labelsize=20)

x, y = np.meshgrid(plotx, ploty)
pmf = pmf - 12

# proj = ax.contourf(x,y,pmf, zdir='z', offset=-12.5, cmap=newcmp, levels=[-12, -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1, 0])
surf = ax.plot_surface(x,y,pmf, rstride=1, cstride=1, linewidth=0, cmap=newcmp, antialiased=False, vmin=-12)
proj = ax.contourf(plotx,ploty,pmf, zdir='z', offset=-13, cmap=newcmp, levels=[-12, -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1, 0])

np.savetxt('pmf.txt', pmf)
ax.grid(False)

ax.w_xaxis.set_pane_color((1.0,1.0,1.0))
ax.w_yaxis.set_pane_color((1.0,1.0,1.0))
ax.w_zaxis.set_pane_color((1.0,1.0,1.0))
ax.w_zaxis.line.set_color((1.0,1.0,1.0))
ax.set_xlim([xmin, xmax])
ax.set_ylim([ymin, ymax])

ax.set_xlabel('PC1',fontsize=24, labelpad=10, rotation=20, weight='bold')
ax.set_ylabel('PC2',fontsize=24, labelpad=10, rotation=-35)
ax.set_xticks([-20,-10,0,10])
ax.set_yticks([-10,0,10])
ax.set_xticklabels([-20,-10,0,10], **axis_font)
ax.set_yticklabels([-10,0,10], **axis_font)
ax.set_zticks([])
ax.xaxis.set_tick_params(pad=0.1)
ax.yaxis.set_tick_params(pad=0.1)

ax.set_xlim3d([xmin, xmax])
ax.set_ylim3d([ymin, ymax])
ax.set_zlim3d(-12.6, 0)
ax.view_init(elev=23, azim=46)

# cl = fig.colorbar(surf, shrink=0.5)
# cl.mappable.set_clim(-12,0)

# ax.set_zscale(1.5)

fig.tight_layout()

plt.savefig('72his3d-apo.png', transparent=True, dpi=300)
plt.show()
