####################################################
####Calculate the halogen bonds formed by the three elements N, O, and S, respectively
####################################################
from __future__ import print_function
import mdtraj as md 
from numpy import *
import matplotlib.pyplot as plt

traj=md.load_xtc('./traj_promol.xtc', top='promol.pdb')
top = traj.topology
print(top)

###select atom N
atom_cl = top.select('resname MOL and name CL1')
atom_c_cl = top.select('resname MOL and name C8')

atom_n_1  = top.select('resid 0 and name N')
atom_c_1  = top.select('resid 0 and name CA')
atom_n_2  = top.select('resid 127 and name N')
atom_c_2  = top.select('resid 126 and name C')

atom_n=concatenate((atom_n_1, atom_n_2))
atom_c=concatenate((atom_c_1, atom_c_2))
n_pair_cl=len(atom_cl)
n_pair_cn=len(atom_n)

###pair-dist
pair_dis_cl_n = array([(i,j) for i in atom_n for j in atom_cl], dtype=int)
###pair-angle-1
pair_angle_1 = array([(i, atom_cl[j], atom_c_cl[j]) for i in atom_n for j in range(n_pair_cl)], dtype=int)
###pair-angle-2
pair_angle_2 = array([(atom_c[i], atom_n[i], j) for i in range(n_pair_cn) for j in atom_cl], dtype=int)


savetxt('INDEX_pair_disi_o.txt', pair_dis_cl_n, fmt=' %d')
savetxt('INDEX_pair_angle_1.txt', pair_angle_1, fmt=' %d')
savetxt('INDEX_pair_angle_2.txt', pair_angle_2, fmt=' %d')

natoms = len(pair_dis_cl_n)

res_pair_dis_cl_n=zeros((natoms, 2)).astype(int)
for i in range(natoms):
    for j in range(2):
        res_pair_dis_cl_n[i,j] = top.atom(pair_dis_cl_n[i,j]).residue.index
savetxt('RES_INDEX_pair_disi_o.txt', res_pair_dis_cl_n, fmt=' %d')

###cal dist
dist_cl_n = md.compute_distances(traj, pair_dis_cl_n, True)
###cal angle-1
angle_1_n = md.compute_angles(traj, pair_angle_1, True)
angle_1_n = rad2deg(angle_1_n)
####cal angle-2
angle_2_n = md.compute_angles(traj, pair_angle_2, True)
angle_2_n = rad2deg(angle_2_n)

####
cutoff_dist_o = [0.35, 0.40]
cutoff_angle_1 = 165
cutoff_angle_2 = 120
dev_angle = 30

###
for c in cutoff_dist_o:
    fp=open("numb_halogen_byframe_cutoff%f.dat" %c, "w")
    fq=open("atom_halogen_byframe_cutoff%f.dat" %c, "w")
    fr=open("resi_halogen_byframe_cutoff%f.dat" %c, "w")
    for i in range(traj.n_frames):
        dang1=abs(angle_1_n[i,:] - cutoff_angle_1)
        dang2=abs(angle_2_n[i,:] - cutoff_angle_2)
#        index= intersect1d(where(dist_cl_o[i,:] < c), where(dang1 <= dev_angle), where(dang2 <= dev_angle))
        index= intersect1d(where(dist_cl_n[i,:] < c), where(dang1 <= dev_angle), where(dang2 <= dev_angle))
        fp.write("%d %d\n" %(i, len(index)))
        for a in index:
            fq.write("%d  %d  %d\n" % (i, pair_dis_cl_n[a,0], pair_dis_cl_n[a,1]))
            fr.write("%d  %d  %d\n" % (i, res_pair_dis_cl_n[a,0], res_pair_dis_cl_n[a,1]))
    fp.close()
    fq.close()
    fr.close()


