####################################################
####Calculate the halogen bonds formed by the three elements N, O, and S, respectively
####################################################
from __future__ import print_function
import mdtraj as md 
from numpy import *
import matplotlib.pyplot as plt

traj=md.load_xtc('./traj_promol.xtc', top='promol.pdb')
top = traj.topology
print(top)

###select atom O
atom_cl = top.select('resname MOL and name CL1')
atom_c_cl = top.select('resname MOL and name C8')

atom_o_1  = top.select('protein and name O')
atom_c_1  = top.select('protein and name C')
atom_o_2  = top.select('resname GLN and name OE1')
atom_c_2  = top.select('resname GLN and name CD')
atom_o_31 = top.select('resname GLU and name OE1') 
atom_o_32 = top.select('resname GLU and name OE2')
atom_c_3  = top.select('resname GLU and name CD')
atom_o_4  = top.select('resname THR and name OG1')
atom_c_4  = top.select('resname THR and name CB')
atom_o_5  = top.select('resname SER and name OG')
atom_c_5  = top.select('resname SER and name CB')

atom_o_all=concatenate((atom_o_1, atom_o_2, atom_o_31, atom_o_32, atom_o_4, atom_o_5))
atom_c_all=concatenate((atom_c_1, atom_c_2, atom_c_3,  atom_c_3,  atom_c_4, atom_c_5))

n_pair_cl=len(atom_cl)
n_pair_co=len(atom_o_all)

###pair-dist
pair_dis_cl_o = array([(i,j) for i in atom_o_all for j in atom_cl], dtype=int)
###pair-angle-1
pair_angle_1 = array([(i, atom_cl[j], atom_c_cl[j]) for i in atom_o_all for j in range(n_pair_cl)], dtype=int)
###pair-angle-2
pair_angle_2 = array([(atom_c_all[i], atom_o_all[i], j) for i in range(n_pair_co) for j in atom_cl], dtype=int)

print(shape(pair_angle_1))
print(shape(pair_angle_2))

savetxt('INDEX_pair_disi_o.txt', pair_dis_cl_o, fmt=' %d')
savetxt('INDEX_pair_angle_1.txt', pair_angle_1, fmt=' %d')
savetxt('INDEX_pair_angle_2.txt', pair_angle_2, fmt=' %d')

natoms = len(pair_dis_cl_o)

res_pair_dis_cl_o=zeros((natoms, 2)).astype(int)
for i in range(natoms):
    for j in range(2):
        res_pair_dis_cl_o[i,j] = top.atom(pair_dis_cl_o[i,j]).residue.index
savetxt('RES_INDEX_pair_disi_o.txt', res_pair_dis_cl_o, fmt=' %d')

###cal dist
dist_cl_o = md.compute_distances(traj, pair_dis_cl_o, True)
###cal angle-1
angle_1_o = md.compute_angles(traj, pair_angle_1, True)
angle_1_o = rad2deg(angle_1_o)
####cal angle-2
angle_2_o = md.compute_angles(traj, pair_angle_2, True)
angle_2_o = rad2deg(angle_2_o)

####
cutoff_dist_o = [0.35, 0.40]
cutoff_angle_1 = 165
cutoff_angle_2 = 120
dev_angle = 30

###
for c in cutoff_dist_o:
    fp=open("numb_halogen_byframe_cutoff%f.dat" %c, "w")
    fq=open("atom_halogen_byframe_cutoff%f.dat" %c, "w")
    fr=open("resi_halogen_byframe_cutoff%f.dat" %c, "w")
    for i in range(traj.n_frames):
        dang1=abs(angle_1_o[i,:] - cutoff_angle_1)
        dang2=abs(angle_2_o[i,:] - cutoff_angle_2)
        index= intersect1d(where(dist_cl_o[i,:] < c), where(dang1 <= dev_angle), where(dang2 <= dev_angle))
        fp.write("%d %d\n" %(i, len(index)))
        for a in index:
            fq.write("%d  %d  %d\n" % (i, pair_dis_cl_o[a,0], pair_dis_cl_o[a,1]))
            fr.write("%d  %d  %d\n" % (i, res_pair_dis_cl_o[a,0], res_pair_dis_cl_o[a,1]))
    fp.close()
    fq.close()
    fr.close()


