####################################################
####Calculate the halogen bonds formed by the three elements N, O, and S, respectively
####################################################
from __future__ import print_function
import mdtraj as md 
from numpy import *
import matplotlib.pyplot as plt

traj=md.load_xtc('./traj_promol.xtc', top='promol.pdb')
top = traj.topology
print(top)

###select atom S
atom_cl = top.select('resname MOL and name CL1')
atom_c_cl = top.select('resname MOL and name C8')

atom_s  = top.select('protein and name SD')
atom_c_1  = top.select('resname MET and name CE')
atom_c_2  = top.select('resname MET and name CG')

n_pair_cl=len(atom_cl)
n_pair_so=len(atom_s)

###pair-dist
pair_dis_cl_s = array([(i,j) for i in atom_s for j in atom_cl], dtype=int)
###pair-angle-1
pair_angle_1 = array([(i, atom_cl[j], atom_c_cl[j]) for i in atom_s for j in range(n_pair_cl)], dtype=int)
###pair-angle-2
pair_angle_2_1 = array([(atom_c_1[i], atom_s[i], j) for i in range(n_pair_so) for j in atom_cl], dtype=int)
pair_angle_2_2 = array([(atom_c_2[i], atom_s[i], j) for i in range(n_pair_so) for j in atom_cl], dtype=int)

print(shape(pair_angle_1))
#print(shape(pair_angle_2))

savetxt('INDEX_pair_disi_o.txt', pair_dis_cl_s, fmt=' %d')
savetxt('INDEX_pair_angle_1.txt', pair_angle_1, fmt=' %d')
savetxt('INDEX_pair_angle_2_1.txt', pair_angle_2_1, fmt=' %d')
savetxt('INDEX_pair_angle_2_2.txt', pair_angle_2_2, fmt=' %d')

natoms = len(pair_dis_cl_s)

res_pair_dis_cl_s=zeros((natoms, 2)).astype(int)
for i in range(natoms):
    for j in range(2):
        res_pair_dis_cl_s[i,j] = top.atom(pair_dis_cl_s[i,j]).residue.index
savetxt('RES_INDEX_pair_disi_o.txt', res_pair_dis_cl_s, fmt=' %d')

###cal dist
dist_cl_s = md.compute_distances(traj, pair_dis_cl_s, True)
###cal angle-1
angle_1_s = md.compute_angles(traj, pair_angle_1, True)
angle_1_s = rad2deg(angle_1_s)
####cal angle-2
angle_2_s_1 = md.compute_angles(traj, pair_angle_2_1, True)
angle_2_s_2 = md.compute_angles(traj, pair_angle_2_1, True)
angle_2_s_1 = rad2deg(angle_2_s_1)
angle_2_s_2 = rad2deg(angle_2_s_2)

####
cutoff_dist_s = [0.35, 0.40]
cutoff_angle_1 = 165
cutoff_angle_2 = 120
dev_angle = 30

###
for c in cutoff_dist_s:
    fp=open("numb_halogen_byframe_cutoff%f.dat" %c, "w")
    fq=open("atom_halogen_byframe_cutoff%f.dat" %c, "w")
    fr=open("resi_halogen_byframe_cutoff%f.dat" %c, "w")
    for i in range(traj.n_frames):
        dang1=abs(angle_1_s[i,:] - cutoff_angle_1)
        dang2_1=abs(angle_2_s_1[i,:] - cutoff_angle_2)
        dang2_2=abs(angle_2_s_2[i,:] - cutoff_angle_2)
        tdang2 = where(concatenate((where(dang2_1 <= dev_angle)[0], where(dang2_2 <= dev_angle)[0])))
        index= intersect1d(where(dist_cl_s[i,:] < c), where(dang1 <= dev_angle),tdang2)
        fp.write("%d %d\n" %(i, len(index)))
        for a in index:
            fq.write("%d  %d  %d\n" % (i, pair_dis_cl_s[a,0], pair_dis_cl_s[a,1]))
            fr.write("%d  %d  %d\n" % (i, res_pair_dis_cl_s[a,0], res_pair_dis_cl_s[a,1]))
    fp.close()
    fq.close()
    fr.close()


