import sys
from numpy import *
import matplotlib as mpl 
import matplotlib.pyplot as plt 
from matplotlib import cm 
from matplotlib import rc 
from matplotlib.ticker import (MultipleLocator, FormatStrFormatter, AutoMinorLocator)
from sklearn.cluster import KMeans
from matplotlib.patches import Circle

mpl.rcParams['font.family']='serif'
mpl.rcParams['figure.subplot.hspace'] = 0.02
mpl.rcParams['figure.subplot.wspace'] = 0.02
mpl.rcParams['lines.linewidth'] = 1.5
mpl.rcParams['figure.subplot.left'] = 0.155
mpl.rcParams['figure.subplot.right'] = 0.99
mpl.rcParams['figure.subplot.bottom'] = 0.15
mpl.rcParams['figure.subplot.top'] = 0.99

rc('text', usetex=True)
axis_font = {'fontname':'serif', 'size':'10.5'}
axis_font_tick = {'labelsize':'10.5'}

data = loadtxt('contact_matrix_2d.txt')
data_cluster = array(data)

sse_list = []
K = range(1, 10)
for i in range(1, 10):
    model = KMeans(n_clusters=i, max_iter=300, init="k-means++")
    model.fit(data_cluster)
    sse_list.append(model.inertia_)
    print(sse_list)

savetxt('sse-scale.txt', sse_list)

sse_list = array(sse_list)/100000
##calculate curvature
classnum = len(array(sse_list))
print(classnum)
sse_curva = zeros((classnum-2))
for i in range(1, classnum-1):
    sse_curva[i-1] = array(sse_list)[i+1] + array(sse_list)[i-1] - 2*array(sse_list)[i]

x_curvature = range(2, classnum)

####plot
fig = plt.figure(figsize=(3.3, 3.3))
ax1 = fig.add_subplot(111)
ax1.plot(array(K), array(sse_list), 'bx-')

ax1.tick_params(axis='both', **axis_font_tick)
ax1.set_xlabel('Class Number', **axis_font)
ax1.set_ylabel(r"SSE(*10$^5$)", **axis_font)

####ax2

left,bottom,width,height = 0.55, 0.55, 0.37, 0.37
ax2=fig.add_axes([left,bottom,width,height])
ax2.plot(x_curvature, sse_curva, 'bx-', color='orange')

ax2.tick_params(axis='both', **axis_font_tick)
ax2.set_xlabel('Class Number', **axis_font)
ax2.set_ylabel(r"Second Derivative(*10$^5$)", **axis_font)

#circle = Circle(xy=(argmax(sse_curva)+2, sse_curva[argmax(sse_curva)]), radius=1/16*(array(sse_curva).max()-array(sse_curva).min()), fc='none',  ec='orange')
#ax2.add_patch(p=circle)

plt.savefig("bestk.png", dpi=300)
plt.show()
